@@ -8,8 +8,9 @@ use std::io::{Error, ErrorKind, Result};
 use std::path::Path;
 use std::process::Command;
 
+#[allow(dead_code)]
 mod mdcat {
-    include!("src/bin/mdcat/args.rs");
+    include!("src/args.rs");
 }
 
 fn gen_completions<P: AsRef<Path>>(out_dir: P) -> Result<()> {
